@@ -33,8 +33,7 @@ knit_print.help_files_with_topic = function(x, options) {
   Rd = db[[which(base == sub('[.]Rd$', '', basename(names(db))))]]
   Rd = extract_Rd(Rd, options$printr.help.sections)
 
-  # TODO: use knitr::pandoc_to()
-  type = knitr::opts_knit$get('rmarkdown.pandoc.to')
+  type = knitr::pandoc_to()
   if (is.null(type)) {
     type = knitr:::out_format()
     if (type == 'html') type = 'HTML' else if (type != 'latex') type = 'txt'
@@ -59,7 +58,7 @@ knit_print.help_files_with_topic = function(x, options) {
     out = gsub('<pre>', '<pre class="r">', out)
   }
 
-  out = knitr:::trimws(out)
+  out = trimws(out)
   # I do not know where _\b came from in the text mode...
   if (type == 'txt') gsub('_\b', '', out) else asis_output(out)
 }
